@@ -1,4 +1,4 @@
-from automon import Logging
+from automon.log import Logging
 from automon.helpers.os import environ
 
 log = Logging(name='SplunkSoarConfig', level=Logging.DEBUG)
@@ -25,7 +25,7 @@ class SplunkSoarConfig:
     def __repr__(self):
         return f'{self.__dict__}'
 
-    def isReady(self):
+    def isReady(self) -> bool:
         if self.host:
             return True
         log.warn(f'bad config')
